# ``KMAdvertisement``
广告Framework，远程控制广告显示，可通过以下参数控制
* 显示状态
* 开始结束时间
* APP名称
* 订阅情况
* 平台
* 支持版本


## 如何接入
* 导入KMAdvertisement.framework
* 导入AFNetworking.framework
* <a href="#接入示例"> 按照接入示例</a>

## 功能
* 视图显示模式
  * <a href="#List">List</a>
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638caf19f0f171670164249.png)
  * <a href="#View">View</a>
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638cb6f268c291670166258.png)
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638cb31fbdfc41670165279.png)
  * <a href="#Scroll">Scroll</a>
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638cb31fbf94b1670165279.png)
  * <a href="#Pop">Pop(暂未实现)</a>
  
  
* 物件支持
  * 多语
  * 黑暗模式
  * 视图圆角，边框
  * 选中与非选中状态
  * 背景色
  * 跳转指定URL
  * tips

## <a id="接入示例">接入示例</a>
#### 视图加载方法
##### 1.绑定视图
![添加方法一](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638ca544dc92c1670161732.png)

##### 2.指定视图
![添加方法二](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638ca570776ea1670161776.png)

```swift
//设置基础参数
KMAdvertisementManager.manager.initConfig(appID: .PDFReaderProIOS,
                                          subscribeType: .unsubscribed,
                                          platform: .iOS)
//测试模式，默认false
KMAdvertisementManager.manager.debug = true

unowned let weakSelf = self
//获取广告数据
KMAdvertisementManager.manager.fetchData { data, error in
    if data != nil {
        for model in data! {
            if model.showType == .scroll {
                //视图加载方法一
                let view = KMAdvertisementManager.manager.show(type: .scroll, data: model, superView: weakSelf.showScrollView) { actionType in
                    print("点击了 scroll 1")
                }
                //视图加载方法二
                weakSelf.advertisementScroll.inputData = model
                weakSelf.advertisementScroll.actionCompletion = { actionItem in
                    print("点击了 scroll 2")
                }
            }
            
            if model.showType == .view {
                //视图加载方法一
                let view =  KMAdvertisementManager.manager.show(type: .view, data: model, superView: weakSelf.showView) { actionItem in
                    print("点击了 view 1")
                }
                
                //视图加载方法二
                weakSelf.advertisementView.inputData = model
                weakSelf.advertisementView.actionCompletion = { actionItem in
                    print("点击了 view 2")
                }
            }
        }
    }
}
```

### 数据格式
##### KMAdvertisementModel
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| appName   | <a href="#AppNameType"> AppNameType</a>   | appName: FilmageEditorMac |  APP名称
| platform  | <a href="#PlatformType"> PlatformType</a> | platform: iOS             |  平台
| showType  | <a href="#ShowType"> ShowType</a>         | showType: "List"          |  APP名称
| subscribeType | <a href="#SubscribeType"> SubscribeType</a> | subscribeType: "subscribed" |  显示类型
| startTime | String 时间戳                              | startTime: "1669709056569"|  APP名称
| endTime   | String 时间戳                              | endTime: "1709709056569 " |  结束时间
| version   | String                                    | appName: "1.3.5"          | 版本
| content   | <a href="#Section"> Section</a>           | content: [Section]         |  内容


###### <a id="Section">Section</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| sectionTitle | <a href="#Text"> Text</a>              | sectionTitle: <a href="#Text"> Text</a> | setion标题 |
| content  | <a href="#Conent"> Conent</a> | content: [<a href="#Conent"> Conent</a>] | 详情 | 

###### <a id="Content">Content</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| index     | Int                                       | index: 0                  |  下标
| title     | <a href="#Text"> Text</a>                 | title: <a href="#Text"> Text</a> | 标题 |
| imageURL  | <a href="#Image"> Image</a>               | imageURL: <a href="#Image"> Image</a> | 图片链接 |
| ipadImageURL | <a href="#Image"> Image</a>            | ipadImageURL: <a href="#Image"> Image</a> | ipad图片链接 |
| linkURL   | <a href="#Language"> Language</a>         | linkURL: <a href="#Language"> Language</a> | 点击链接 |
| tips      | <a href="#Language"> Language</a>         | tips: <a href="#Language"> Language</a> | tips |
| button    | <a href="#Text"> Text</a>                 | button: <a href="#Text"> Text</a> | 按钮样式 |
| actionType| <a href="#ActionType"> ActionType</a>     | actionType: "URL"         |  响应类型 |

###### <a id="Text">Text</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| font      | <a href="#Font"> Font</a>                 | font: <a href="#Font"> Font</a>  | 字体 |
| color     | <a href="#Color"> Color</a>               | color: <a href="#Color"> Color</a> | 颜色 |
| background | <a href="#Background"> Background</a>    | background: <a href="#Background"> Background</a> | 背景 |
| language  | <a href="#Language"> Language</a>         | language: <a href="#Language"> Language</a> | 多语 |

###### <a id="Image">Image</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| height | <a href="#Language"> Language</a>            | height: <a href="#Language"> Language</a> | 高亮 |
| normal | <a href="#Language"> Language</a>            | normal: <a href="#Language"> Language</a> | 正常 |
| background | <a href="#Background"> Background</a>    | background: <a href="#Background"> Background</a> | 背景颜色 |

###### <a id="Language">Language</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| en        | String                                    | en: "en"                  |  英文
| zh_TW     | String                                    | zhTW: "繁中"               |  繁中
| zh_CN     | String                                    | zhCN: "简中"               |  简中

###### <a id="Background">Background</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| color     | <a href="#Color"> Color</a>               | color:<a href="#Color"> Color</a> |  颜色  |
| layer     | <a href="#Layer"> Layer</a>               | layer:<a href="#Color"> Color</a> |  图层  |

###### <a id="Color">Color</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| height | <a href="#AppNameType"> AppNameType</a>   | appName: FilmageEditorMac |  APP名称
| normal  | <a href="#Conent"> Conent</a> | platform: iOS             |  平台

###### <a id="ColorState">ColorState</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| dark      | <a href="#ColorInfo"> ColorInfo</a>       | dark:{"hex":"#C7C8CC","alpha":1} | 黑暗模式 |
| universal | <a href="#ColorInfo"> ColorInfo</a>       | universal:{"hex":"#C7C8CC","alpha":1} | 正常模式 |

##### <a id="ColorInfo">ColorInfo</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| hex       | String                                    | hex: "#FFFFFF"            | 颜色16进制     |
| alpha     | Float                                     | alpha: 1.0                |  透明度

###### <a id="Font">Text</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| name      | String                                    | name: "AppleSystemUIFont" | 字体名称       |
| size      | Int                                       | size: 13                  | 字体大小       |

###### <a id="Layer">Layer</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| cornerRadius | Float                                  | cornerRadius: 15          |  圆角          |
| borderWidth | Float                                   | borderWidth: 1            |  边框宽度       |
| borderColor | <a href="#Color"> Color</a>             | borderColor: <a href="#Color"> Color</a> |  颜色 |

##### <a id="List">List</a>

###### json示例
```json
{
    "appName":"FilmageEditorMac",
    "platform":"Mac",
    "showType":"list",
    "version":"1.3.5",
    "startTime":"1669709056569",
    "endTime":"1689709056569",
    "subscribeType":"unsubscribed",
    "content":[
        {
            "sectionTitle":{
                "font":{
                    "name":"AppleSystemUIFont",
                    "size":13
                },
                "color":{
                    "height":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    },
                    "normal":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    }
                },
                "language":{
                    "en":"PDF Pro系列",
                    "zh_TW":"PDF Pro系列",
                    "zh_CN":"PDF Pro系列"
                }
            },
            "content":[
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "tips":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "imageURL":{
"height":{
                            "en":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_TW":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_CN":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png"
                        },
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "tips":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "imageURL":{
"height":{
                            "en":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_TW":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_CN":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png"
                        },
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                }
            ]
        },
{
            "sectionTitle":{
                "font":{
                    "name":"AppleSystemUIFont",
                    "size":13
                },
                "color":{
                    "height":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    },
                    "normal":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    }
                },
                "language":{
                    "en":"Filmage 系列",
                    "zh_TW":"Filmage 系列",
                    "zh_CN":"Filmage 系列"
                }
            },
            "content":[
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "tips":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "imageURL":{
"height":{
                            "en":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_TW":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_CN":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png"
                        },
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "tips":{
                            "en":"The Warmest Black Friday Deal!",
                            "zh_TW":"老闆哭了~趁黑色星期五升級Write-on Video Pro最划算!",
                            "zh_CN":"老板哭了~趁黑色星期五升级V视频Pro最划算!"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "imageURL":{
"height":{
                            "en":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_TW":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png",
                            "zh_CN":"https://iap-s3.kdanmobile.com/resource/ff29cfce-b64a-46ca-b260-f57c9e3240b8/blackFriday20211020_2x.png"
                        },
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638858600d7471669879904.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                }
            ]
        }
    ]
}
```

#####  <a id="View">View</a>
###### json示例
```json
{
    "appName":"PDFReaderProIOS",
    "platform":"iOS",
    "showType":"view",
    "version":"1.3.5",
    "startTime":"1669709056569",
    "endTime":"1709709056569",
    "subscribeType":"unsubscribed",
    "content":[
        {
            "content":[
                {
"actionType":"URL",
                    "imageURL":{
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638b23df050501670063071.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638b23df050501670063071.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638b23df050501670063071.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    },
"actionType":"comparative"
                }
            ]
        }
    ]
}
```

#####  <a id="Scroll">Scroll</a>
###### json示例
```json
{
    "appName":"PDFReaderProIOS",
    "platform":"iOS",
    "showType":"scroll",
    "version":"1.3.5",
    "startTime":"1669709056569",
    "endTime":"1700709056569",
    "subscribeType":"unsubscribed",
    "content":[
        {
            "content":[
                {
                    "actionType":"URL",
                    "imageURL":{
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/6389b1bb019111669968315.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/6389b1bb019111669968315.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/6389b1baed2f41669968314.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                },
                {
                    "actionType":"URL",
                    "imageURL":{
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638b04d197d561670055121.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638b04d197d561670055121.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638b04d197ff01670055121.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                },
                {
                    "actionType":"URL",
                    "title":{
                        "font":{
                            "name":"Helvetica-Bold",
                            "size":20
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"All-New PDF Reader Pro Windows Released!",
                            "zh_TW":"PDF Reader Pro Windows版全新發佈！",
                            "zh_CN":"PDF Reader Pro Windows版全新发布！"
                        }
                    },
                    "button":{
                        "font":{
                            "name":"PingFangSC-Semibold",
                            "size":13
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Learn More",
                            "zh_TW":"更多資訊",
                            "zh_CN":"了解更多"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":15,
                                "borderWidth":1,
                                "borderColor":{
                                    "color":{
                                        "height":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        },
                                        "normal":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "imageURL":{
                        "normal":{
                            "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/6389b82d63b181669969965.png",
                            "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/6389b82d63b181669969965.png",
                            "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/6389b82d63b181669969965.png"
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo",
                        "zh_TW":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo",
                        "zh_CN":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo"
                    }
                }
            ]
        }
    ]
}
```

#####  <a id="Pop">Pop</a>
###### json示例
```
```

#### 代码块
* <a id="AppNameType">KMAdvertisementAppNameType</a>
```swift
//APP类型
public enum KMAdvertisementAppNameType: String, Codable {
    case RecordIt = "RecordIt"
    case RecordItPro = "RecordItPro"
    case RecordItDMG = "RecordItDMG"
    case FilmageScreen = "FilmageScreen"
    case FilmageScreenPro = "FilmageScreenPro"
    case FilmageScreenDMG = "FilmageScreenDMG"
    case FilmageEditorMac = "FilmageEditorMac"
    case FilmageEditorMacPro = "FilmageEditorMacPro"
    case FilmageEditorMacDMG = "FilmageEditorMacDMG"
    case FilmageConverterMac = "FilmageConverterMac"
    case FilmageConverterMacPro = "FilmageConverterMacPro"
    case FilmageConverterMacDMG = "FilmageConverterMacDMG"
    case FilmagePlayerMac = "FilmagePlayerMac"
    case FilmagePlayerMacPro = "FilmagePlayerMacPro"
    case FilmagePlayerMacDMG = "FilmagePlayerMacDMG"
    case PDFReaderProMac = "PDFReaderProMac"
    case PDFReaderProMacPro = "PDFReaderProMacPro"
    case PDFReaderProMacDMG = "PDFReaderProMacDMG"
    case PDFReaderProIOS = "PDFReaderProIOS"
    case PDFReaderProIOSPro = "PDFReaderProIOSPro"
}
```

* <a id="PlatformType">KMAdvertisementPlatformType</a>
```swift
//平台
public enum KMAdvertisementPlatformType: String, Codable {
    case unknow = "unknow"
    case Mac = "Mac" //
    case iOS = "iOS" //
}
```

* <a id="ShowType">KMAdvertisementShowType</a>
```swift
//显示样式
public enum KMAdvertisementShowType: String, Codable {
    case unknow = "unknow"
    case list = "list" //列表
    case pop = "pop"//弹窗
    case scroll = "scroll"//循环
    case view = "view" //视图显示
}
```


* <a id="SubscribeType">KMAdvertisementSubscribeType</a>
```swift
//订阅状态
public enum KMAdvertisementSubscribeType: String, Codable {
    case unknow = "unknow"
    case unsubscribed = "unsubscribed"//未订阅
    case subscribed = "subscribed"//已订阅
}

```

* <a id="ActionType">KMAdvertisementActionType</a>
```swift
//点击视图后跳转选项
public enum KMAdvertisementActionType: String, Codable {
    case unknow = "unknow"
    case URL = "URL"//链接
    case comparative = "comparative"//比价表
}
```

* <a id="LanguageType">KMAdvertisementLanguageType</a>
```swift
//多语
public enum KMAdvertisementLanguageType: String {
    case unknow = "unknow"
    case en = "en"//
    case zhCN = "zhCN"//
    case zhTW = "zhTW"//
}

```
